neon_receipt: Log in files received from NEON

View source: R/neon_receipt.R

neon_receiptR Documentation

Log in files received from NEON

Description

Interactively processes NEON sample shipping file using barcodes and writes a receipt file and database records.

Usage

neon_receipt(fname)

Arguments

fname

character. File name (within the user's “neonPath”) for a sample shipping file provided by NEON.

Details

Requires access to a user configuration file written using write_config and properly formatted and structured data files and directories. See package man page CRDSutils for details.

Writes output to the “Processed” folder within the “neonPath” directory documented in the user's configuration file.


SPATIAL-Lab/CRDSutils documentation built on Dec. 12, 2024, 3:23 a.m.