| neon_receipt | R Documentation |
Interactively processes NEON sample shipping file using barcodes and writes a receipt file and database records.
neon_receipt(fname)
fname |
character. File name (within the user's “neonPath”) for a sample shipping file provided by NEON. |
Requires access to a user configuration file written using write_config and properly formatted and structured data files and directories. See package man page CRDSutils for details.
Writes output to the “Processed” folder within the “neonPath” directory documented in the user's configuration file.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.